pub async fn execute(command: Option<(&str, &ArgMatches)>) -> Result<(), Error>Expand description
Execute the command specified by the command line arguments.
Errors
Returns an error if the command is not recognized or if an error occurs while executing the command.