pub async fn fetch(config: Option<&PathBuf>) -> Result<(), Error>Expand description
Fetch data from the origin.
Arguments
config- Optional path to the configuration file. If not provided, the default configuration file will be used. This file is expected to be in TOML format. The default file isohlcv.tomland is expected to be in the current working directory or in/etc/ohlcv.
Errors
Returns an error if the data cannot be fetched or if the configuration file cannot be loaded.