pub async fn init(config: Option<&PathBuf>) -> Result<(), Error>Expand description
Initialize the database
Arguments
config- Optional path to the configuration file. If not provided, the default configuration file will be used. This file is expected to be in TOML format. The default file isohlcv.tomland is expected to be in the current working directory or in/etc/ohlcv.
Errors
Returns an error if the database cannot be initialized or if the configuration file cannot be loaded.