Module config

Module config 

Configuration for ohlcv-ctl.

Structs

CoinConfig
Configuration for a coin.
Config
Top-level configuration structure.

Constants

CONFIG_FILE
Name of the default configuration file.
CONFIG_PATHS
Default paths to search for the configuration file if not specified by the user either through a command-line argument or environment variable. The paths are appended with CONFIG_FILE to form the full path to the configuration file. Paths are searched in order, and the first file found is used.

Type Aliases

ExchangeMap
Map of exchange names to the coin’s symbol on that exchange.