Config

Struct Config 

pub struct Config {
    pub database: DbType,
    pub coins: Vec<CoinConfig>,
    /* private fields */
}
Top-level configuration structure.

Fields

database: DbType

Database connection information.

coins: Vec<CoinConfig>

List of coins to fetch.

Implementations

Source

impl Config

pub fn load(path: Option<impl AsRef<Path> + Debug>) -> Result<Self, Error>

Load the configuration from the specified file.

Errors

This function returns an error if the file cannot be read or if the configuration is not valid TOML defined by the Config struct.

pub fn user_agent(&self) -> &str

Get the user agent string to use for HTTP requests.