Function ohlcv_ctl::command::drop

source ·
pub async fn drop(all: bool, config: Option<&PathBuf>) -> Result<(), Error>
Drop tables from the database.

Arguments

  • all - Whether to drop all tables. If false, only tables for the configured coins will be dropped.
  • config - Optional path to the configuration file. If not provided, the default configuration file will be used. This file is expected to be in TOML format. The default file is ohlcv.toml and is expected to be in the current working directory or in /etc/ohlcv.

Errors

Returns an error if the tables cannot be dropped or if the configuration file cannot be loaded.