Function ohlcv_ctl::command::execute

source ·
pub async fn execute(command: Option<(&str, &ArgMatches)>) -> Result<(), Error>
Execute the command specified by the command line arguments.

Errors

Returns an error if the command is not recognized or if an error occurs while executing the command.