Module ohlcv_ctl::config

source ·
Configuration for ohlcv-ctl.

Structs

Constants

  • Name of the default configuration file.
  • Default paths to search for the configuration file if not specified by the user either through a command-line argument or environment variable. The paths are appended with CONFIG_FILE to form the full path to the configuration file. Paths are searched in order, and the first file found is used.

Type Aliases

  • Map of exchange names to the coin’s symbol on that exchange.